aboutsummaryrefslogtreecommitdiffstats
path: root/epan/dissectors/packet-pgm.c
diff options
context:
space:
mode:
authorGuy Harris <guy@alum.mit.edu>2014-06-20 09:43:28 -0700
committerGuy Harris <guy@alum.mit.edu>2014-06-20 16:43:56 +0000
commitce3d2ff3ded3eccb9d64c6cb46c64ad8f8a837b9 (patch)
tree8a4ddc4ec1607716254ada75c607094da614f131 /epan/dissectors/packet-pgm.c
parent4df6b5178496422ddfc3b9256af763b847d1a2c7 (diff)
Rename dissector_add_handle() to dissector_add_for_decode_as().
Hopefully that name makes it clear what the routiner's purpose is, and will encourage people to use it rather than using dissector_add_uint() with a bogus integer value. Change-Id: Ic5be456d0ad40b176aab01712ab7b13aed5de2a8 Reviewed-on: https://code.wireshark.org/review/2483 Reviewed-by: Guy Harris <guy@alum.mit.edu>
Diffstat (limited to 'epan/dissectors/packet-pgm.c')
-rw-r--r--epan/dissectors/packet-pgm.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/epan/dissectors/packet-pgm.c b/epan/dissectors/packet-pgm.c
index 6dc1f3c95f..486746a5eb 100644
--- a/epan/dissectors/packet-pgm.c
+++ b/epan/dissectors/packet-pgm.c
@@ -1412,7 +1412,7 @@ proto_register_pgm(void)
* (Note: Initially the ports are set to zero and the ports
* are not registered so the dissecting of PGM
* encapsulated in UDP packets is off by default;
* dissector_add_handle is called so that pgm
* is available for 'decode-as'
*/
pgm_module = prefs_register_protocol(proto_pgm, proto_reg_handoff_pgm);
@@ -1451,7 +1451,7 @@ proto_reg_handoff_pgm(void)
if (! initialized) {
pgm_handle = create_dissector_handle(dissect_pgm, proto_pgm);
- dissector_add_handle("udp.port", pgm_handle); /* for 'decode-as' */
+ dissector_add_for_decode_as("udp.port", pgm_handle);
dissector_add_uint("ip.proto", IP_PROTO_PGM, pgm_handle);
data_handle = find_dissector("data");
initialized = TRUE;
@@ -1412,7 +1412,7 @@ proto_register_pgm(void)
* are not registered so the dissecting of PGM
* encapsulated in UDP packets is off by default;
- * dissector_add_handle is called so that pgm
+ * dissector_add_for_decode_as is called so that pgm
* is available for 'decode-as'
*/